colcon - collective construction
================================

``colcon`` is a command line tool to improve the workflow of building, testing and using multiple software packages.
It automates the process, handles the ordering and sets up the environment to use the packages.

For more information see `colcon.readthedocs.io <https://colcon.readthedocs.io>`_.
